starter

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 26, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Option

type Option func(*Options)

func CronSchedule

func CronSchedule(cronSchedule string) Option

CronSchedule sets the cron schedule for the workflow.

func EnableEagerStart

func EnableEagerStart(b bool) Option

EnableEagerStart requests eager execution for this workflow, if a local worker is available.

func ID

func ID(id string) Option

ID sets the workflow ID.

func Memo

func Memo(memo map[string]any) Option

Memo sets the memo for the workflow.

func Priority

func Priority(priority temporal.Priority) Option

Priority sets the priority for the workflow.

func RetryPolicy

func RetryPolicy(rp *temporal.RetryPolicy) Option

RetryPolicy sets the retry policy for the workflow.

func StartDelay

func StartDelay(delay time.Duration) Option

StartDelay sets the delay before dispatching the first workflow task.

func StaticDetails

func StaticDetails(details string) Option

StaticDetails sets the static details for the workflow.

func StaticSummary

func StaticSummary(summary string) Option

StaticSummary sets the static summary for the workflow.

func TaskQueue

func TaskQueue(taskQueue string) Option

TaskQueue sets the task queue for the workflow.

func TypedSearchAttributes

func TypedSearchAttributes(searchAttributes temporal.SearchAttributes) Option

TypedSearchAttributes sets the typed search attributes for the workflow.

func VersioningOverride

func VersioningOverride(override client.VersioningOverride) Option

VersioningOverride sets the versioning override for the workflow.

func WaitResult added in v0.3.0

func WaitResult(wait bool) Option

func WorkflowExecutionErrorWhenAlreadyStarted

func WorkflowExecutionErrorWhenAlreadyStarted(b bool) Option

WorkflowExecutionErrorWhenAlreadyStarted sets whether to return an error when the workflow is already running.

func WorkflowExecutionTimeout

func WorkflowExecutionTimeout(timeout time.Duration) Option

WorkflowExecutionTimeout sets the timeout for the entire workflow execution.

func WorkflowIDConflictPolicy

func WorkflowIDConflictPolicy(policy enums.WorkflowIdConflictPolicy) Option

WorkflowIDConflictPolicy sets the workflow ID conflict policy.

func WorkflowIDReusePolicy

func WorkflowIDReusePolicy(policy enums.WorkflowIdReusePolicy) Option

WorkflowIDReusePolicy sets the workflow ID reuse policy.

func WorkflowRunTimeout

func WorkflowRunTimeout(timeout time.Duration) Option

WorkflowRunTimeout sets the timeout for a single workflow run.

func WorkflowTaskTimeout

func WorkflowTaskTimeout(timeout time.Duration) Option

WorkflowTaskTimeout sets the timeout for a workflow task.

type Options added in v0.0.3

type Options struct {
	client.StartWorkflowOptions
	WaitResult bool
}

func NewOptions

func NewOptions(taskQueue string, opts ...Option) Options

NewOptions creates a new StartWorkflowOptions with the given options.

Jump to