Documentation
¶
Index ¶
- type Option
- func CronSchedule(cronSchedule string) Option
- func EnableEagerStart(b bool) Option
- func ID(id string) Option
- func Memo(memo map[string]any) Option
- func Priority(priority temporal.Priority) Option
- func RetryPolicy(rp *temporal.RetryPolicy) Option
- func StartDelay(delay time.Duration) Option
- func StaticDetails(details string) Option
- func StaticSummary(summary string) Option
- func TaskQueue(taskQueue string) Option
- func TypedSearchAttributes(searchAttributes temporal.SearchAttributes) Option
- func VersioningOverride(override client.VersioningOverride) Option
- func WaitResult(wait bool) Option
- func WorkflowExecutionErrorWhenAlreadyStarted(b bool) Option
- func WorkflowExecutionTimeout(timeout time.Duration) Option
- func WorkflowIDConflictPolicy(policy enums.WorkflowIdConflictPolicy) Option
- func WorkflowIDReusePolicy(policy enums.WorkflowIdReusePolicy) Option
- func WorkflowRunTimeout(timeout time.Duration) Option
- func WorkflowTaskTimeout(timeout time.Duration) Option
- type Options
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Option ¶
type Option func(*Options)
func CronSchedule ¶
CronSchedule sets the cron schedule for the workflow.
func EnableEagerStart ¶
EnableEagerStart requests eager execution for this workflow, if a local worker is available.
func RetryPolicy ¶
func RetryPolicy(rp *temporal.RetryPolicy) Option
RetryPolicy sets the retry policy for the workflow.
func StartDelay ¶
StartDelay sets the delay before dispatching the first workflow task.
func StaticDetails ¶
StaticDetails sets the static details for the workflow.
func StaticSummary ¶
StaticSummary sets the static summary for the workflow.
func TypedSearchAttributes ¶
func TypedSearchAttributes(searchAttributes temporal.SearchAttributes) Option
TypedSearchAttributes sets the typed search attributes for the workflow.
func VersioningOverride ¶
func VersioningOverride(override client.VersioningOverride) Option
VersioningOverride sets the versioning override for the workflow.
func WaitResult ¶ added in v0.3.0
func WorkflowExecutionErrorWhenAlreadyStarted ¶
WorkflowExecutionErrorWhenAlreadyStarted sets whether to return an error when the workflow is already running.
func WorkflowExecutionTimeout ¶
WorkflowExecutionTimeout sets the timeout for the entire workflow execution.
func WorkflowIDConflictPolicy ¶
func WorkflowIDConflictPolicy(policy enums.WorkflowIdConflictPolicy) Option
WorkflowIDConflictPolicy sets the workflow ID conflict policy.
func WorkflowIDReusePolicy ¶
func WorkflowIDReusePolicy(policy enums.WorkflowIdReusePolicy) Option
WorkflowIDReusePolicy sets the workflow ID reuse policy.
func WorkflowRunTimeout ¶
WorkflowRunTimeout sets the timeout for a single workflow run.
func WorkflowTaskTimeout ¶
WorkflowTaskTimeout sets the timeout for a workflow task.
type Options ¶ added in v0.0.3
type Options struct {
client.StartWorkflowOptions
WaitResult bool
}
func NewOptions ¶
NewOptions creates a new StartWorkflowOptions with the given options.